@@ -3,6 +3,16 @@ use libc::{c_char, c_void};
 
 use base::{SecAccessRef, SecKeychainRef};
 
+pub const SEC_KEYCHAIN_SETTINGS_VERS1: u32 = 1;
+
+#[repr(C)]
+pub struct SecKeychainSettings {
+    pub version: u32,
+    pub lockOnSleep: Boolean,
+    pub useLockInterval: Boolean,
+    pub lockInterval: u32,
+}
+
 extern "C" {
     pub fn SecKeychainGetTypeID() -> CFTypeID;
     #[cfg(target_os = "macos")]
@@ -23,4 +33,6 @@ extern "C" {
                              password: *const c_void,
                              usePassword: Boolean)
                              -> OSStatus;
+    #[cfg(target_os = "macos")]
+    pub fn SecKeychainSetSettings(keychain: SecKeychainRef, newSettings: *const SecKeychainSettings) -> OSStatus;
 }
